@@ -142,16 +142,38 @@ class Console_Table
     var $_charset = 'utf-8';
 
     /**
-     * Border character.
+     * Border characters.
+     * Allowed keys:
+     * - intersection - intersection ("+")
+     * - horizontal - horizontal rule character ("-")
+     * - vertical - vertical rule character ("|")
      *
-     * @var string
+     * @var array
      */
-    var $_border = CONSOLE_TABLE_BORDER_ASCII;
+    var $_border = array(
+        'intersection' => '+',
+        'horizontal' => '-',
+        'vertical' => '|',
+    );
+
+    /**
+     * If borders are shown or not
+     * Allowed keys: top, right, bottom, left, inner: true and false
+     *
+     * @var array
+     */
+    var $_borderVisibility = array(
+        'top'    => true,
+        'right'  => true,
+        'bottom' => true,
+        'left'   => true,
+        'inner'  => true
+    );
 
     /**
      * Whether the data has ANSI colors.
      *
-     * @var boolean
+     * @var Console_Color2
      */
     var $_ansiColor = false;
 
@@ -174,11 +196,11 @@ class Console_Table
                            $charset = null, $color = false)
     {
         $this->_defaultAlign = $align;
-        $this->_border       = $border;
+        $this->setBorder($border);
         $this->_padding      = $padding;
-        $this->_ansiColor    = $color;
-        if ($this->_ansiColor) {
-            include_once 'Console/Color.php';
+        if ($color) {
+            include_once 'Console/Color2.php';
+            $this->_ansiColor = new Console_Color2();
         }
         if (!empty($charset)) {
             $this->setCharset($charset);
@@ -249,6 +271,60 @@ class Console_Table
         setlocale(LC_CTYPE, $locale);
     }
 
+    /**
+     * Set the table border settings
+     *
+     * Border definition modes:
+     * - CONSOLE_TABLE_BORDER_ASCII: Default border with +, - and |
+     * - array with keys "intersection", "horizontal" and "vertical"
+     * - single character string that sets all three of the array keys
+     *
+     * @param mixed $border Border definition
+     *
+     * @return void
+     * @see $_border
+     */
+    function setBorder($border)
+    {
+        if ($border === CONSOLE_TABLE_BORDER_ASCII) {
+            $intersection = '+';
+            $horizontal = '-';
+            $vertical = '|';
+        } else if (is_string($border)) {
+            $intersection = $horizontal = $vertical = $border;
+        } else if ($border == '') {
+            $intersection = $horizontal = $vertical = '';
+        } else {
+            extract($border);
+        }
+
+        $this->_border = array(
+            'intersection' => $intersection,
+            'horizontal' => $horizontal,
+            'vertical' => $vertical,
+        );
+    }
+
+    /**
+     * Set which borders shall be shown.
+     *
+     * @param array $visibility Visibility settings.
+     *                          Allowed keys: left, right, top, bottom, inner
+     *
+     * @return void
+     * @see    $_borderVisibility
+     */
+    function setBorderVisibility($visibility)
+    {
+        $this->_borderVisibility = array_merge(
+            $this->_borderVisibility,
+            array_intersect_key(
+                $visibility,
+                $this->_borderVisibility
+            )
+        );
+    }
+
     /**
      * Sets the alignment for the columns.
      *
@@ -564,9 +640,7 @@ class Console_Table
             return '';
         }
 
-        $rule      = $this->_border == CONSOLE_TABLE_BORDER_ASCII
-            ? '|'
-            : $this->_border;
+        $vertical = $this->_border['vertical'];
         $separator = $this->_getSeparator();
 
         $return = array();
@@ -583,9 +657,13 @@ class Console_Table
             }
 
             if ($this->_data[$i] !== CONSOLE_TABLE_HORIZONTAL_RULE) {
-                $row_begin    = $rule . str_repeat(' ', $this->_padding);
-                $row_end      = str_repeat(' ', $this->_padding) . $rule;
-                $implode_char = str_repeat(' ', $this->_padding) . $rule
+                $row_begin = $this->_borderVisibility['left']
+                    ? $vertical . str_repeat(' ', $this->_padding)
+                    : '';
+                $row_end = $this->_borderVisibility['right']
+                    ? str_repeat(' ', $this->_padding) . $vertical
+                    : '';
+                $implode_char = str_repeat(' ', $this->_padding) . $vertical
                     . str_repeat(' ', $this->_padding);
                 $return[]     = $row_begin
                     . implode($implode_char, $this->_data[$i]) . $row_end;
@@ -597,7 +675,12 @@ class Console_Table
 
         $return = implode(PHP_EOL, $return);
         if (!empty($separator)) {
-            $return = $separator . PHP_EOL . $return . PHP_EOL . $separator;
+            if ($this->_borderVisibility['inner']) {
+                $return = $separator . PHP_EOL . $return;
+            }
+            if ($this->_borderVisibility['bottom']) {
+                $return .= PHP_EOL . $separator;
+            }
         }
         $return .= PHP_EOL;
 
@@ -620,22 +703,22 @@ class Console_Table
             return;
         }
 
-        if ($this->_border == CONSOLE_TABLE_BORDER_ASCII) {
-            $rule = '-';
-            $sect = '+';
-        } else {
-            $rule = $sect = $this->_border;
-        }
+        $horizontal = $this->_border['horizontal'];
+        $intersection = $this->_border['intersection'];
 
         $return = array();
         foreach ($this->_cell_lengths as $cl) {
-            $return[] = str_repeat($rule, $cl);
+            $return[] = str_repeat($horizontal, $cl);
         }
 
-        $row_begin    = $sect . str_repeat($rule, $this->_padding);
-        $row_end      = str_repeat($rule, $this->_padding) . $sect;
-        $implode_char = str_repeat($rule, $this->_padding) . $sect
-            . str_repeat($rule, $this->_padding);
+        $row_begin = $this->_borderVisibility['left']
+            ? $intersection . str_repeat($horizontal, $this->_padding)
+            : '';
+        $row_end = $this->_borderVisibility['right']
+            ? str_repeat($horizontal, $this->_padding) . $intersection
+            : '';
+        $implode_char = str_repeat($horizontal, $this->_padding) . $intersection
+            . str_repeat($horizontal, $this->_padding);
 
         return $row_begin . implode($implode_char, $return) . $row_end;
     }
@@ -669,16 +752,18 @@ class Console_Table
             }
         }
 
-        $rule         = $this->_border == CONSOLE_TABLE_BORDER_ASCII
-            ? '|'
-            : $this->_border;
-        $row_begin    = $rule . str_repeat(' ', $this->_padding);
-        $row_end      = str_repeat(' ', $this->_padding) . $rule;
-        $implode_char = str_repeat(' ', $this->_padding) . $rule
+        $vertical = $this->_border['vertical'];
+        $row_begin = $this->_borderVisibility['left']
+            ? $vertical . str_repeat(' ', $this->_padding)
+            : '';
+        $row_end = $this->_borderVisibility['right']
+            ? str_repeat(' ', $this->_padding) . $vertical
+            : '';
+        $implode_char = str_repeat(' ', $this->_padding) . $vertical
             . str_repeat(' ', $this->_padding);
 
         $separator = $this->_getSeparator();
-        if (!empty($separator)) {
+        if (!empty($separator) && $this->_borderVisibility['top']) {
             $return[] = $separator;
         }
         for ($j = 0; $j < count($this->_headers); $j++) {
@@ -719,8 +804,10 @@ class Console_Table
         }
 
         // Set default column alignments
-        for ($i = count($this->_col_align); $i < $this->_max_cols; $i++) {
-            $this->_col_align[$i] = $pad;
+        for ($i = 0; $i < $this->_max_cols; $i++) {
+            if (!isset($this->_col_align[$i])) {
+                $this->_col_align[$i] = $pad;
+            }
         }
     }
 
@@ -781,7 +868,7 @@ class Console_Table
 
         // Strip ANSI color codes if requested.
         if ($this->_ansiColor) {
-            $str = Console_Color::strip($str);
+            $str = $this->_ansiColor->strip($str);
         }
 
         // Cache expensive function_exists() calls.
